pub fn generate_project(config: ProjectConfig) -> Result<()>Expand description
Generate a new project based on the provided configuration
pub fn generate_project(config: ProjectConfig) -> Result<()>Generate a new project based on the provided configuration